apply_rotation_promax: Apply factor rotation to discrimination matrix and latent...

View source: R/sim-utils.R

apply_rotation_promaxR Documentation

Apply factor rotation to discrimination matrix and latent traits

Description

Supports "promax" (via stats::promax) and GPArotation methods ("varimax", "oblimin", etc.). Transforms the discrimination matrix a, the latent trait matrix theta, and the correlation matrix Corr accordingly.

Usage

apply_rotation_promax(a, theta, Corr, rotate, D, promax_m = 4)

Arguments

a

I \times D discrimination (loading) matrix.

theta

N \times D latent trait matrix.

Corr

D \times D correlation matrix.

rotate

Rotation method name (character).

D

Number of dimensions.

promax_m

Power parameter for "promax" (default 4).

Value

A named list with components a, theta, Corr.


ForceChoice documentation built on Sept. 13, 2026, 1:06 a.m.