extract_rhat_matrix: Extract R-hat values for a matrix parameter from a Stan...

View source: R/tools.R

extract_rhat_matrixR Documentation

Extract R-hat values for a matrix parameter from a Stan summary

Description

Extract R-hat values for a matrix parameter from a Stan summary

Usage

extract_rhat_matrix(stan.sum, param_name, nrow, ncol)

Arguments

stan.sum

Stan summary matrix (rownames encode parameter indices).

param_name

Parameter name prefix (e.g. "theta").

nrow, ncol

Dimensions of the output matrix.

Value

A numeric matrix of R-hat values.


ForceChoice documentation built on Sept. 13, 2026, 1:06 a.m.