extract_rhat_vector: Extract R-hat values for a vector parameter from a Stan...

View source: R/tools.R

extract_rhat_vectorR Documentation

Extract R-hat values for a vector parameter from a Stan summary

Description

Extract R-hat values for a vector parameter from a Stan summary

Usage

extract_rhat_vector(stan.sum, param_name, n)

Arguments

stan.sum

Stan summary matrix.

param_name

Parameter name prefix (e.g. "delta1").

n

Expected length of the output vector.

Value

A numeric vector of R-hat values (NA where not found).


ForceChoice documentation built on Sept. 13, 2026, 1:06 a.m.