| make_item_prob_cdm | R Documentation |
Computes the probability of endorsing an item for each attribute mastery
pattern under the specified CDM condensation rule (DINA, DINO, ACDM, or
GDINA). p0 is the lower-bound (guessing) probability and
p1 is the upper-bound (1 - slipping) probability.
make_item_prob_cdm(patterns, model, p0, p1, mono.constraint = TRUE)
patterns |
A binary matrix of attribute mastery patterns. |
model |
One of |
p0 |
Lower-bound probability (guessing). |
p1 |
Upper-bound probability (1 - slipping). |
mono.constraint |
Logical; if |
A named numeric vector of probabilities, one per pattern row.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.