model.FCMIRT: Compute FCMIRT Forced-Choice Pattern Probabilities

View source: R/sim.data.FCMIRT.R

model.FCMIRTR Documentation

Compute FCMIRT Forced-Choice Pattern Probabilities

Description

Compute FCMIRT Forced-Choice Pattern Probabilities

Usage

model.FCMIRT(theta, par, patterns.total, patterns)

Arguments

theta

N x D matrix of latent trait values.

par

I x (D + 3) MIRT item parameter matrix, where b is the item difficulty and the item-level linear predictor is a' theta - b.

patterns.total

List of full-ranking pattern matrices.

patterns

List of observed pattern matrices.

Value

N x sum(pattern counts) probability matrix. For each block, item endorsement probabilities are first computed by model.MIRT, transformed to logits, and then combined with a sequential Luce/Plackett rule. MOLE and PICK probabilities are obtained by summing compatible full-ranking probabilities and normalizing over the observed block patterns.


ForceChoice documentation built on Sept. 13, 2026, 1:06 a.m.