resolve_block_items: Auto-detect block.items from forced-choice ranking data

View source: R/istem-helpers.R

resolve_block_itemsR Documentation

Auto-detect block.items from forced-choice ranking data

Description

Parses ranking strings like "2>1>3" to extract the set of item indices in each block. Only works when data columns contain character ranking strings.

Usage

resolve_block_items(block.items, data)

Arguments

block.items

User-supplied block.items or NULL.

data

The forced-choice data matrix.

Value

A list of integer vectors (one per block), or NULL if auto-detection is not possible.


ForceChoice documentation built on Sept. 13, 2026, 1:06 a.m.