| get_precedent_patterns | R Documentation |
For each attribute mastery pattern, identifies which other patterns are proper subsets (i.e., mastering a subset of the attributes). Used to enforce the GDINA monotonicity constraint: mastering more attributes should never decrease the success probability.
get_precedent_patterns(patterns)
patterns |
A binary matrix of attribute mastery patterns
( |
Equivalent to preloclist in the GDINA R package.
A list of length L; the l-th element is an integer
vector of row indices corresponding to patterns that are proper
subsets of pattern l.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.