View source: R/sim.data.FCMIRT.R
| model.FCMIRT | R Documentation |
Compute FCMIRT Forced-Choice Pattern Probabilities
model.FCMIRT(theta, par, patterns.total, patterns)
theta |
N x D matrix of latent trait values. |
par |
I x (D + 3) MIRT item parameter matrix, where b is the item difficulty and the item-level linear predictor is a' theta - b. |
patterns.total |
List of full-ranking pattern matrices. |
patterns |
List of observed pattern matrices. |
N x sum(pattern counts) probability matrix. For each block,
item endorsement probabilities are first computed by model.MIRT,
transformed to logits, and then combined with a sequential
Luce/Plackett rule. MOLE and PICK probabilities are obtained by summing
compatible full-ranking probabilities and normalizing over the observed
block patterns.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.