View source: R/sim.data.FCMIRT.R
| sim.data.FCMIRT | R Documentation |
Simulates forced-choice ranking data using a MIRT item response model
("m1pl" through "m4pl") as the item-level endorsement model.
Forced-choice responses are generated by applying the sequential
Luce/Plackett choice rule to the logits of the item-level endorsement
probabilities, with RANK, MOLE, and PICK patterns handled by
model.FCMIRT.
For identification, item difficulty/intercept parameters b are
centered within each forced-choice block so that their block sum is zero.
sim.data.FCMIRT(
N.person = 1000,
N.block = 10,
I.block = 2,
D = 3,
model = "m2pl",
fc.type = "RANK",
control = NULL
)
N.person |
Number of persons. |
N.block |
Number of forced-choice blocks. |
I.block |
Number of items per block when |
D |
Number of latent dimensions. If |
model |
MIRT model type: |
fc.type |
Forced-choice response type: |
control |
Optional list. Supported entries are |
An object of class "data.FCMIRT", a list containing
data, response, theta, par, Q.matrix,
block.items, Corr, model, patterns,
patterns.total, probability, prob, and
data-generating arguments.
fit.FCMIRT, model.FCMIRT
set.seed(123)
sim <- sim.data.FCMIRT(N.person = 20, N.block = 3, I.block = 2,
D = 2, model = "m2pl", fc.type = "RANK")
str(sim$data)
head(sim$response)
dim(sim$prob)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.